.. _dg-dg_plot_1D:

dg/dg_plot_1D.py
================

**Description**


Script for plotting 1D DG FEM data stored in VTK files




:download:`source code </../sfepy/examples/dg/dg_plot_1D.py>`

.. literalinclude:: /../sfepy/examples/dg/dg_plot_1D.py

